/*
 * Limit.java
 *
 * Class to abstract an initialising Apama event used by the StockWatch application.
 * A Limit event signals a request to the correlator to start looking for a fall in 
 * the traded price of a stock below a certain value. 
 *
 * $Copyright(c) 2002,  2004 - 2006 Progress Software Corporation. All Rights Reserved.$ 
 * $Copyright (c) 2013,2019 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA, and/or its subsidiaries and/or its affiliates and/or their licensors.$ 
 * Use, reproduction, transfer, publication or disclosure is prohibited except as specifically provided for in your License Agreement with Software AG 
 *
 * $Revision: 359265 $
 */

import com.apama.jmon.Event;


public class Limit extends Event {
	private static final long serialVersionUID = 16L;
    /** The id of the user in the application */
    public long userID;

    /** The name or symbol of the stock to monitor */
    public String stockName;

    /** The price of the stock trade below which the user should be notified */
    public double priceFloor;
    

    /**
     * No argument constructor
     */ 
    public Limit() {
	this(0, "", 0);
    }
    

    /**
     * Construct a Limit object and set the instance variables
     * 
     * @param  userID         The id of the user in the application
     * @param  stockName      The name or symbol of the stock to monitor 
     * @param  priceFloor     The price of the stock trade below which the user 
     *                        should be notified 
     */
    public Limit(long userID, String stockName, double priceFloor){
	this.userID = userID;
	this.stockName = stockName;
	this.priceFloor = priceFloor;
    }
}

