/*
 * Match.java
 *
 * Class to abstract an Apama match event used by the VWAP application.
 * The match event gives details of the percentage change in successive
 * VWAP values for a given stock, the actual values of the successive VWAPs
 * and the period the VWAPs were calculated over.
 *
 * $Copyright(c) 2002,  2004 - 2006 Progress Software Corporation. All Rights Reserved.$ 
 * $Copyright (c) 2013,2019 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA, and/or its subsidiaries and/or its affiliates and/or their licensors.$ 
 * Use, reproduction, transfer, publication or disclosure is prohibited except as specifically provided for in your License Agreement with Software AG 
 *
 * $Revision: 359265 $
 */

import com.apama.jmon.Event;


public class Match extends Event {
	private static final long serialVersionUID = 22L;
    /** The symbol of the stock */
    public String stockName;

    /** The period over which the VWAP values were calculated */
    public double period;

    /** The percentage change between the successive VWAPs */
    public double percentageChange;

    /** The value of the first VWAP */
    public double vwap1;

    /** The value of the second VWAP */
    public double vwap2;
    

    /**
     * No argument constructor
     */
    public Match() {
	this("", 0, 0, 0, 0);
    }


    /**
     * Construct a Match object and set the instance variables
     * 
     * @param  stockName          The symbol of the stock
     * @param  period             The period over which the VWAP values were calculated
     * @param  percentageChange   The percentage change between the successive VWAPs
     * @param  vwap1              The value of the first VWAP  
     * @param  vwap2              The value of the second VWAP 
     */
    public Match(String stockName, double period, double percentageChange,
		 double vwap1, double vwap2){
	this.stockName = stockName;
	this.period = period;
	this.percentageChange = percentageChange;
	this.vwap1 = vwap1;
	this.vwap2 = vwap2;
    }

}

