/*
 * VwapWatch.java
 *
 * Class to abstract an initialising Apama event used by the VWAP application.
 * A VwapWatch event signals a request to the correlator to start calculating
 * VWAPs for a given stock, over a given duration. It also defines the 
 * percentage change in successive VWAPs for which a user would want to be 
 * notified of.
 *
 * $Copyright(c) 2002,  2004 - 2006 Progress Software Corporation. All Rights Reserved.$ 
 * $Copyright (c) 2013,2019 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA, and/or its subsidiaries and/or its affiliates and/or their licensors.$ 
 * Use, reproduction, transfer, publication or disclosure is prohibited except as specifically provided for in your License Agreement with Software AG 
 *
 * $Revision: 359265 $
 */

import com.apama.jmon.Event;


public class VwapWatch extends Event {
	private static final long serialVersionUID = 20L;
    /** The symbol of the stock */
    public String stockName;

    /** The period used in calculating the VWAPs */
    public long period;

    /** The percentage change in successive VWAPs */
    public double percentageChange;
     
    
    /**
     * No argument constructor
     */   
    public VwapWatch() {
	this("", 0, 0);
    }


    /**
     * Construct a VwapWatch object and set the instance variables
     * 
     * @param  stockName           The symbol of the stock
     * @param  period              The period used in calculating the VWAPs
     * @param  percentageChange    The percentage change in successive VWAPs 
     */
    public VwapWatch(String stockName, long period, double percentageChange){
	this.stockName = stockName;
	this.period = period;
	this.percentageChange = percentageChange;
    }
}

